@@ -31,8 +31,16 @@ wfwebtool.writeParams = function () {
                     'Memory: ' + params.Memory + '<br>' +
                     'Estimated Number of Jobs: ' + (params.TotalEstimatedJobs || '?');
 
-                if (params.RequestType == 'Resubmission')
-                    $('#optclone').remove();
+                if (params.RequestType == 'Resubmission') {
+                    function removeClone () {
+                        var select = $('#optclone');
+                        if (select.length == 1)
+                            select.remove();
+                        else
+                            setTimeout(removeClone, 500);
+                    };
+                    removeClone ();
+                }
 
                 $('a').each(function () {
 
@@ -107,6 +115,9 @@ wfwebtool.fillSimilar = function () {
         url: '/similarwfs',
         data: {workflow: wf},            // Then we fill the list of multiple workflows
         success: function (data) {
+            if (!data.similar.length)
+                return;
+
             var button = document.getElementById("showmulti");
             button.style.display = '';
             var wfdiv = document.getElementById("wflist");
@@ -149,6 +160,36 @@ wfwebtool.predict = function () {
 };
 
 
+wfwebtool.checkFiles = function () {
+
+    var wf = this.url.searchParams.get('workflow');
+    $.ajax({
+            url: '/problem_files',
+            data: {workflow: wf},
+            success: function (data) {
+                if (data.length) {
+                    $('#filehead').show();
+                }
+
+                data.forEach(function(fileName) {
+                        $('#fileinfo').
+                            append('<li>' + fileName + ': <span id="status:' + fileName +
+                                   '"><img class="loading" src="/static/img/loading.gif" alt="Loading..."></span></li>');
+                        $.ajax({
+                                url: '/file_exists',
+                                data: {filename: fileName},
+                                success: function (status) {
+                                    var status_element = document.getElementById('status:' + fileName);
+                                    status_element.innerHTML = status['xrdfs_locate'] ? 'Exists' : 'Not Found';
+                                }
+                            })
+                    })
+            }
+        });
+
+}
+
+
 function reset(wkfl) {
     theSpan = document.getElementById('reset');
     theSpan.innerHTML = 'Refreshing page, please wait...';
@@ -169,4 +210,5 @@ wfwebtool.workflowTable = function () {
     this.writeParams();
     this.fillSimilar();
     this.predict();
+    this.checkFiles();
 };
